==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/NumericCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { NumericCellInfoDescription } from "./NumericCellInfoDescription";
/**
 * @hidden
 */
export let NumericCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumericCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (NumericCellInfoDescriptionMetadata.a == null) {
                NumericCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumericCellInfoDescriptionMetadata.c(NumericCellInfoDescriptionMetadata.a);
            }
            if (a.j(NumericCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(NumericCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("NumericValue", "Number:double");
            a.item("HasDecimalValue", "Boolean");
            a.item("FormatStringOverride", "String");
            a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
            a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
            a.item("NegativePrefix", "String");
            a.item("PositivePrefix", "String");
            a.item("NegativeSuffix", "String");
            a.item("PositiveSuffix", "String");
            a.item("MaxFractionDigits", "Number:int");
            a.item("MinFractionDigits", "Number:int");
            a.item("MinIntegerDigits", "Number:int");
            a.item("ShowGroupingSeparator", "Boolean");
        }
        static d(a) {
            NumericCellInfoDescriptionMetadata.b(a);
            a.aa("NumericCellInfo", () => new NumericCellInfoDescription());
            a.z("NumericCellInfo", NumericCellInfoDescriptionMetadata.a);
        }
    }
    NumericCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(NumericCellInfoDescriptionMetadata, 'NumericCellInfoDescriptionMetadata');
    NumericCellInfoDescriptionMetadata.a = null;
    return NumericCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NumericCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { NumericCellInfoDescription } from "./NumericCellInfoDescription";
/**
 * @hidden
 */
export let NumericCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumericCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (NumericCellInfoDescriptionMetadata.a == null) {
                NumericCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumericCellInfoDescriptionMetadata.c(NumericCellInfoDescriptionMetadata.a);
            }
            if (a.k(NumericCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(NumericCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("NumericValue", "Number:double");
            a.item("HasDecimalValue", "Boolean");
            a.item("FormatStringOverride", "String");
            a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
            a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
            a.item("NegativePrefix", "String");
            a.item("PositivePrefix", "String");
            a.item("NegativeSuffix", "String");
            a.item("PositiveSuffix", "String");
            a.item("MaxFractionDigits", "Number:int");
            a.item("MinFractionDigits", "Number:int");
            a.item("MinIntegerDigits", "Number:int");
            a.item("ShowGroupingSeparator", "Boolean");
        }
        static d(a) {
            NumericCellInfoDescriptionMetadata.b(a);
            a.ac("NumericCellInfo", () => new NumericCellInfoDescription());
            a.ab("NumericCellInfo", NumericCellInfoDescriptionMetadata.a);
        }
    }
    NumericCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(NumericCellInfoDescriptionMetadata, 'NumericCellInfoDescriptionMetadata');
    NumericCellInfoDescriptionMetadata.a = null;
    return NumericCellInfoDescriptionMetadata;
})();
